import type { MetadataFiller } from '../messages/MetadataFiller';
import type { MessageMetadataType } from '../messages/baseMessageSchemas';
import type { HandlerSpy, HandlerSpyParams, PublicHandlerSpy } from '../queues/HandlerSpy';
import type { EventRegistry } from './EventRegistry';
import type { AnyEventHandler, SingleEventHandler, CommonEventDefinition, CommonEventDefinitionConsumerSchemaType, EventTypeNames, CommonEventDefinitionPublisherSchemaType } from './eventTypes';
export declare class DomainEventEmitter<SupportedEvents extends CommonEventDefinition[]> {
    private readonly eventRegistry;
    private readonly eventHandlerMap;
    private readonly anyHandlers;
    private readonly metadataFiller;
    private _handlerSpy;
    constructor({ eventRegistry, metadataFiller, }: {
        eventRegistry: EventRegistry<SupportedEvents>;
        metadataFiller: MetadataFiller;
    }, options: {
        handlerSpy?: HandlerSpy<object> | HandlerSpyParams | boolean;
    });
    get handlerSpy(): PublicHandlerSpy<CommonEventDefinitionConsumerSchemaType<SupportedEvents[number]>>;
    emit<SupportedEvent extends SupportedEvents[number]>(supportedEvent: SupportedEvent, data: Omit<CommonEventDefinitionPublisherSchemaType<SupportedEvent>, 'type'>, metadata?: Partial<MessageMetadataType>): Promise<Omit<CommonEventDefinitionConsumerSchemaType<SupportedEvent>, 'type'>>;
    /**
     * Register handler for a specific event
     */
    on<EventTypeName extends EventTypeNames<SupportedEvents[number]>>(eventTypeName: EventTypeName, handler: SingleEventHandler<SupportedEvents, EventTypeName>): void;
    /**
     * Register handler for multiple events
     */
    onMany<EventTypeName extends EventTypeNames<SupportedEvents[number]>>(eventTypeNames: EventTypeName[], handler: SingleEventHandler<SupportedEvents, EventTypeName>): void;
    /**
     * Register handler for all events supported by the emitter
     */
    onAny(handler: AnyEventHandler<SupportedEvents>): void;
    private addOnHandler;
}
